@@ -1,3 +1,4 @@
+import itertools
 from typing import Any, Dict, List, Optional, Union
 
 import aiohttp
@@ -7,7 +8,7 @@ from PicImageSearch.model import EHentaiItem, EHentaiResponse
 from pyquery import PyQuery
 
 from .config import config
-from .utils import handle_img
+from .utils import handle_img, shorten_url
 
 
 class EHentaiResponseAioHttp:
@@ -64,18 +65,37 @@ async def search_result_filter(
 ) -> List[str]:
     if not res.raw:
         return ["EHentai 搜索结果为空"]
-        # 尽可能过滤掉图集，除非只有图集
-    if non_image_set_list := [i for i in res.raw if i.type != "Image Set"]:
-        res.raw = non_image_set_list
-    selected_res = res.raw[0]
-    # 优先找汉化版
-    for i in res.raw:
-        if "translated" in i.tags and "chinese" in i.tags:
-            selected_res = i
-            break
+    # 尽可能过滤掉非预期结果(大概
+    priority = {
+        "Doujinshi": 0,
+        "Manga": 0,
+        "Artist CG": 0,
+        "Game CG": 0,
+        "Image Set": 1,
+        "Non-H": 2,
+        "Western": 3,
+        "Misc": 4,
+    }
+    res.raw.sort(key=lambda x: priority[x.type], reverse=True)
+    for key, group in itertools.groupby(res.raw, key=lambda x: x.type):
+        group_list = list(group)
+        if priority[key] > 0 and len(res.raw) != len(group_list):
+            res.raw = [i for i in res.raw if i not in group_list]
+
+    # 优先找汉化版或原版
+    if chinese_res := [
+        i for i in res.raw if all(tag in i.tags for tag in ["translated", "chinese"])
+    ]:
+        selected_res = chinese_res[0]
+    elif not_translated_res := [i for i in res.raw if "translated" not in i.tags]:
+        selected_res = not_translated_res[0]
+    else:
+        selected_res = res.raw[0]
+
     thumbnail = await handle_img(
         selected_res.thumbnail, proxy, hide_img, config.exhentai_cookies
     )
+    _url = await shorten_url(selected_res.url)
     res_list = [
         "EHentai 搜索结果",
         thumbnail,
@@ -83,7 +103,6 @@ async def search_result_filter(
         f"类型：{selected_res.type}",
         f"日期：{selected_res.date}",
         f"来源：{selected_res.url}",
-        "-" * 20,
-        f"搜索页面：{res.url}",
+        f"搜索页面：{_url}",
     ]
     return ["\n".join([i for i in res_list if i != ""])]
