@@ -52,9 +52,9 @@ async def saucenao_search(
                         selected_res.url = i
             thumbnail = await handle_img(selected_res.thumbnail, proxy, hide_img)
             if selected_res.origin["data"].get("source"):
-                source = shorten_url(selected_res.origin["data"]["source"])
+                source = await shorten_url(selected_res.origin["data"]["source"])
             else:
-                source = shorten_url(await get_source(selected_res.url, proxy))
+                source = await shorten_url(await get_source(selected_res.url, proxy))
             # 如果结果为 doujin ，尝试返回日文标题而不是英文标题
             if selected_res.index_id in saucenao_db["doujin"]:  # type: ignore
                 if title := (
@@ -62,15 +62,17 @@ async def saucenao_search(
                     or selected_res.origin["data"].get("eng_name")
                 ):
                     selected_res.title = title
-            _url = shorten_url(selected_res.url)
+            _url = await shorten_url(selected_res.url)
             res_list = [
                 f"SauceNAO（{selected_res.similarity}%）",
-                f"{thumbnail}",
-                f"{selected_res.title}",
-                f"Author：{selected_res.author}" if selected_res.author else "",
+                thumbnail,
+                selected_res.title,
+                f"作者：{selected_res.author}" if selected_res.author else "",
                 _url,
-                f"Source：{source}" if source else "",
+                f"来源：{source}" if source else "",
             ]
+            if res.long_remaining < 10:
+                final_res.append(f"⚠️️ SauceNAO 24h 内仅剩 {res.long_remaining} 次使用次数")
             final_res.append("\n".join([i for i in res_list if i != ""]))
             if (
                 selected_res.similarity < config.saucenao_low_acc
